@@ -13,6 +13,7 @@ from .types import (
     UUID,
     Argument,
     Base64,
+    BigInt,
     Boolean,
     Context,
     Date,
@@ -41,7 +42,7 @@ from .types import (
 from .utils.module_loading import lazy_import
 from .utils.resolve_only_args import resolve_only_args
 
-VERSION = (3, 1, 0, "final", 0)
+VERSION = (3, 1, 1, "final", 0)
 
 
 __version__ = get_version(VERSION)
@@ -50,6 +51,7 @@ __all__ = [
     "__version__",
     "Argument",
     "Base64",
+    "BigInt",
     "Boolean",
     "ClientIDMutation",
     "Connection",
