@@ -1,10 +1,7 @@
-from collections import OrderedDict
-
-import six
+from enum import Enum as PyEnum
 
 from graphene.utils.subclass_with_meta import SubclassWithMeta_Meta
 
-from ..pyutils.compat import Enum as PyEnum
 from .base import BaseOptions, BaseType
 from .unmountedtype import UnmountedType
 
@@ -24,14 +21,14 @@ class EnumOptions(BaseOptions):
 
 
 class EnumMeta(SubclassWithMeta_Meta):
-    def __new__(cls, name, bases, classdict, **options):
-        enum_members = OrderedDict(classdict, __eq__=eq_enum)
+    def __new__(cls, name_, bases, classdict, **options):
+        enum_members = dict(classdict, __eq__=eq_enum)
         # We remove the Meta attribute from the class to not collide
         # with the enum values.
         enum_members.pop("Meta", None)
         enum = PyEnum(cls.__name__, enum_members)
         return SubclassWithMeta_Meta.__new__(
-            cls, name, bases, OrderedDict(classdict, __enum__=enum), **options
+            cls, name_, bases, dict(classdict, __enum__=enum), **options
         )
 
     def get(cls, value):
@@ -41,16 +38,24 @@ class EnumMeta(SubclassWithMeta_Meta):
         return cls._meta.enum[value]
 
     def __prepare__(name, bases, **kwargs):  # noqa: N805
-        return OrderedDict()
+        return {}
 
     def __call__(cls, *args, **kwargs):  # noqa: N805
         if cls is Enum:
             description = kwargs.pop("description", None)
-            return cls.from_enum(PyEnum(*args, **kwargs), description=description)
+            deprecation_reason = kwargs.pop("deprecation_reason", None)
+            return cls.from_enum(
+                PyEnum(*args, **kwargs),
+                description=description,
+                deprecation_reason=deprecation_reason,
+            )
         return super(EnumMeta, cls).__call__(*args, **kwargs)
         # return cls._meta.enum(*args, **kwargs)
 
-    def from_enum(cls, enum, description=None, deprecation_reason=None):  # noqa: N805
+    def from_enum(
+        cls, enum, name=None, description=None, deprecation_reason=None
+    ):  # noqa: N805
+        name = name or enum.__name__
         description = description or enum.__doc__
         meta_dict = {
             "enum": enum,
@@ -58,10 +63,34 @@ class EnumMeta(SubclassWithMeta_Meta):
             "deprecation_reason": deprecation_reason,
         }
         meta_class = type("Meta", (object,), meta_dict)
-        return type(meta_class.enum.__name__, (Enum,), {"Meta": meta_class})
+        return type(name, (Enum,), {"Meta": meta_class})
 
 
-class Enum(six.with_metaclass(EnumMeta, UnmountedType, BaseType)):
+class Enum(UnmountedType, BaseType, metaclass=EnumMeta):
+    """
+    Enum type definition
+
+    Defines a static set of values that can be provided as a Field, Argument or InputField.
+
+    .. code:: python
+
+        from graphene import Enum
+
+        class NameFormat(Enum):
+            FIRST_LAST = "first_last"
+            LAST_FIRST = "last_first"
+
+    Meta:
+        enum (optional, Enum): Python enum to use as a base for GraphQL Enum.
+
+        name (optional, str): Name of the GraphQL type (must be unique in schema). Defaults to class
+            name.
+        description (optional, str): Description of the GraphQL type in the schema. Defaults to class
+            docstring.
+        deprecation_reason (optional, str): Setting this value indicates that the enum is
+            depreciated and may provide instruction or reason on how for clients to proceed.
+    """
+
     @classmethod
     def __init_subclass_with_meta__(cls, enum=None, _meta=None, **options):
         if not _meta:
